From a3f42f1a4ff714abe8315237fc37dba8940dd9e6 Mon Sep 17 00:00:00 2001
From: Scott Snyder <scott.snyder@cern.ch>
Date: Fri, 16 Dec 2016 19:03:36 +0100
Subject: [PATCH] 'root 6.08 fix.' (AthenaROOTAccess-00-10-16)

	* Tagging AthenaROOTAccess-00-10-16.
	* python/dumpers.py: root 6.08 fix.

2016-12-10  scott snyder  <snyder@bnl.gov>

	* Tagging AthenaROOTAccess-00-10-15.
	* Add xAOD::ForwardEventInfoContainer, xAOD::MBTSModuleContainer,
	xAOD::ZdcModuleContainer, xAOD::TrigRingerRingsContainer_v2.

2016-12-05  scott snyder  <snyder@bnl.gov>

	* Tagging AthenaROOTAccess-00-10-14.
	* python/dumpers.py (_typedefs): Add CaloRings and RingSet.

2016-11-01  scott snyder  <snyder@bnl.gov>

	* Tagging AthenaROOTAccess-00-10-13.
	* No longer have a direct dependency on CxxUtils.

...
(Long ChangeLog diff - truncated)
---
 .../AthenaROOTAccess/IAuxBranches.h           |  47 ---
 .../AthenaROOTAccess/ProxyMap.h               |  16 +-
 .../AthenaROOTAccess/TBranchAlias.h           |   8 +-
 .../AthenaROOTAccess/TTreeTrans.h             |  10 +-
 .../AthenaROOTAccess/CMakeLists.txt           |  14 +-
 .../AthenaROOTAccess/cmt/requirements         |   2 +-
 .../AthenaROOTAccess/python/dumpers.py        |  15 +-
 .../AthenaROOTAccess/python/transientTree.py  |   4 +-
 .../AthenaROOTAccess/src/AuxStoreARA.cxx      | 290 ++------------
 .../AthenaROOTAccess/src/AuxStoreARA.h        |  98 ++---
 .../AthenaROOTAccess/src/ProxyMap.cxx         |   2 +-
 .../src/RootAuxVectorFactory.cxx              | 372 ------------------
 .../src/RootAuxVectorFactory.h                | 318 ---------------
 .../AthenaROOTAccess/src/TBranchAlias.cxx     |  16 +-
 .../AthenaROOTAccess/src/TTreeTrans.cxx       |   2 +-
 15 files changed, 122 insertions(+), 1092 deletions(-)
 delete mode 100644 PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/IAuxBranches.h
 delete mode 100644 PhysicsAnalysis/AthenaROOTAccess/src/RootAuxVectorFactory.cxx
 delete mode 100644 PhysicsAnalysis/AthenaROOTAccess/src/RootAuxVectorFactory.h

diff --git a/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/IAuxBranches.h b/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/IAuxBranches.h
deleted file mode 100644
index 57016cf33bc..00000000000
--- a/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/IAuxBranches.h
+++ /dev/null
@@ -1,47 +0,0 @@
-// This file's extension implies that it's C, but it's really -*- C++ -*-.
-
-/*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
-*/
-
-// $Id$
-/**
- * @file IAuxBranches.h
- * @author scott snyder <snyder@bnl.gov>
- * @date Jul, 2014
- * @brief xxx
- */
-
-
-#ifndef ATHENAROOTACCESS_IAUXBRANCHES_H
-#define ATHENAROOTACCESS_IAUXBRANCHES_H
-
-
-#include "AthContainersInterfaces/AuxTypes.h"
-#include "GaudiKernel/StatusCode.h"
-#include <utility>
-#include <string>
-#include <vector>
-class TBranch;
-
-
-namespace AthenaROOTAccess {
-
-
-class IAuxBranches
-{
-public:
-  virtual ~IAuxBranches() {}
-
-  typedef std::pair<std::string, TBranch*> auxpair_t;
-  virtual std::vector<auxpair_t> auxBranches() const = 0;
-  virtual TBranch* findAuxBranch (SG::auxid_t auxid) const = 0;
-  virtual StatusCode readAuxBranch (TBranch& br, void* p, long long entry) = 0;
-};
-
-
-} // namespace AthenaROOTAccess
-
-
-
-#endif // not ATHENAROOTACCESS_IAUXBRANCHES_H
diff --git a/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/TBranchAlias.h b/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/TBranchAlias.h
index 9d625108895..0d7d2afac4b 100644
--- a/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/TBranchAlias.h
+++ b/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/TBranchAlias.h
@@ -17,7 +17,7 @@
 #define ATHENAROOTACCESS_TBRANCHALIAS_H
 
 
-#include "AthenaROOTAccess/IAuxBranches.h"
+#include "AthContainersRoot/IAuxBranches.h"
 #include "GaudiKernel/ClassID.h"
 #include "AthenaKernel/IStringPool.h"
 #include "TBranch.h"
@@ -55,7 +55,7 @@ class IARAFixup;
  * Note: writing to the branch is unimplemented and may behave strangely!
  */
 class TBranchAlias
-  : public TBranch, public IAuxBranches
+  : public TBranch, public SG::IAuxBranches
 {
 public:
   /// Destructor.
@@ -111,9 +111,11 @@ public:
   virtual const char* GetClassName() const override;
 
 
+  virtual const std::string& getName() const override;
   virtual std::vector<IAuxBranches::auxpair_t> auxBranches() const override;
-  virtual TBranch* findAuxBranch (SG::auxid_t auxid) const override;
+  virtual TBranch* findAuxBranch (SG::auxid_t auxid) override;
   virtual StatusCode readAuxBranch (TBranch& br, void* p, long long entry) override;
+  virtual StatusCode readAuxBranch (TBranch& br, void* p, const std::type_info& ti, long long entry) override;
 
 
   /**
diff --git a/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/TTreeTrans.h b/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/TTreeTrans.h
index 1be7db4a4f0..e016bfe4196 100644
--- a/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/TTreeTrans.h
+++ b/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/TTreeTrans.h
@@ -17,7 +17,7 @@
 #define ATHENAROOTACCESS_TTREETRANS_H
 
 #include "AthenaROOTAccess/TTreeBranchMap.h"
-#include "SGTools/IProxyDictWithPool.h"
+#include "AthenaKernel/IProxyDict.h"
 #include "Rtypes.h"
 #include <set>
 #include <string>
@@ -72,7 +72,7 @@ class TTreeTransDeleter;
  */
 class TTreeTrans
   : public TTreeBranchMap,
-    public IProxyDictWithPool
+    public IProxyDict
 {
 public:
   //========================================================================
@@ -134,7 +134,7 @@ public:
    * The current tree is the one which gets installed as the source
    * when @c ElementLink's are constructed.
    */
-  static IProxyDictWithPool* setCurTree (IProxyDictWithPool* tree);
+  static IProxyDict* setCurTree (IProxyDict* tree);
 
 
   /**
@@ -151,7 +151,7 @@ public:
 
   private:
     /// The previous current tree.
-    IProxyDictWithPool* m_saved;
+    IProxyDict* m_saved;
   };
 
 
@@ -208,7 +208,7 @@ public:
 
   //@}
   //========================================================================
-  /** @name IProxyDictWithPool interface. */
+  /** @name IProxyDict interface. */
   //@{
 
 
diff --git a/PhysicsAnalysis/AthenaROOTAccess/CMakeLists.txt b/PhysicsAnalysis/AthenaROOTAccess/CMakeLists.txt
index d5793b5ed9b..de11246e434 100644
--- a/PhysicsAnalysis/AthenaROOTAccess/CMakeLists.txt
+++ b/PhysicsAnalysis/AthenaROOTAccess/CMakeLists.txt
@@ -9,13 +9,13 @@ atlas_subdir( AthenaROOTAccess )
 atlas_depends_on_subdirs( PUBLIC
                           Control/AthContainersInterfaces
                           Control/AthenaKernel
-                          Control/CxxUtils
                           Control/SGTools
                           GaudiKernel
                           PRIVATE
                           AtlasTest/TestTools
                           Control/AthAllocators
                           Control/AthContainers
+                          Control/AthContainersRoot
                           Control/AthLinks
                           Control/RootUtils
                           Database/AthenaPOOL/AthenaPoolCnvSvc
@@ -33,32 +33,32 @@ atlas_add_library( AthenaROOTAccess
                    src/*.cxx
                    PUBLIC_HEADERS AthenaROOTAccess
                    PRIVATE_INCLUDE_DIRS ${ROOT_INCLUDE_DIRS}
-                   LINK_LIBRARIES AthenaKernel CxxUtils SGTools GaudiKernel RootUtilsPyROOT AthenaPoolCnvSvcLib
-                   PRIVATE_LINK_LIBRARIES ${ROOT_LIBRARIES} TestTools AthAllocators AthContainers AthLinks RootUtils PersistentDataModel PersistentDataModelTPCnv xAODHIEvent xAODMuon xAODTracking )
+                   LINK_LIBRARIES AthenaKernel SGTools GaudiKernel RootUtilsPyROOT AthenaPoolCnvSvcLib
+                   PRIVATE_LINK_LIBRARIES ${ROOT_LIBRARIES} TestTools AthAllocators AthContainers AthContainersRoot AthLinks RootUtils PersistentDataModel PersistentDataModelTPCnv xAODHIEvent xAODMuon xAODTracking )
 
 atlas_add_dictionary( AthenaROOTAccessDict
                       AthenaROOTAccess/AthenaROOTAccessDict.h
                       AthenaROOTAccess/selection.xml
                       INCLUDE_DIRS ${ROOT_INCLUDE_DIRS}
-                      LINK_LIBRARIES ${ROOT_LIBRARIES} AthenaKernel CxxUtils SGTools GaudiKernel TestTools AthAllocators AthContainers AthLinks RootUtils RootUtilsPyROOT AthenaPoolCnvSvcLib PersistentDataModel PersistentDataModelTPCnv xAODHIEvent xAODMuon xAODTracking AthenaROOTAccess )
+                      LINK_LIBRARIES ${ROOT_LIBRARIES} AthenaKernel SGTools GaudiKernel TestTools AthAllocators AthContainers AthContainersRoot AthLinks RootUtils RootUtilsPyROOT AthenaPoolCnvSvcLib PersistentDataModel PersistentDataModelTPCnv xAODHIEvent xAODMuon xAODTracking AthenaROOTAccess )
 
 atlas_add_dictionary( AthenaROOTAccessTestDict
                       AthenaROOTAccess/AthenaROOTAccessTestDict.h
                       AthenaROOTAccess/test_selection.xml
                       INCLUDE_DIRS ${ROOT_INCLUDE_DIRS}
-                      LINK_LIBRARIES ${ROOT_LIBRARIES} AthenaKernel CxxUtils SGTools GaudiKernel TestTools AthAllocators AthContainers AthLinks RootUtils RootUtilsPyROOT AthenaPoolCnvSvcLib PersistentDataModel PersistentDataModelTPCnv xAODHIEvent xAODMuon xAODTracking AthenaROOTAccess )
+                      LINK_LIBRARIES ${ROOT_LIBRARIES} AthenaKernel SGTools GaudiKernel TestTools AthAllocators AthContainers AthContainersRoot AthLinks RootUtils RootUtilsPyROOT AthenaPoolCnvSvcLib PersistentDataModel PersistentDataModelTPCnv xAODHIEvent xAODMuon xAODTracking AthenaROOTAccess )
 
 atlas_add_test( DVCollectionProxy_test
                 SOURCES
                 test/DVCollectionProxy_test.cxx
                 INCLUDE_DIRS ${ROOT_INCLUDE_DIRS}
-                LINK_LIBRARIES ${ROOT_LIBRARIES} AthenaKernel CxxUtils SGTools GaudiKernel TestTools AthAllocators AthContainers AthLinks RootUtils RootUtilsPyROOT AthenaPoolCnvSvcLib PersistentDataModel PersistentDataModelTPCnv xAODHIEvent xAODMuon xAODTracking AthenaROOTAccess )
+                LINK_LIBRARIES ${ROOT_LIBRARIES} AthenaKernel SGTools GaudiKernel TestTools AthAllocators AthContainers AthContainersRoot AthLinks RootUtils RootUtilsPyROOT AthenaPoolCnvSvcLib PersistentDataModel PersistentDataModelTPCnv xAODHIEvent xAODMuon xAODTracking AthenaROOTAccess )
 
 atlas_add_test( DataBucketVoid_test
                 SOURCES
                 test/DataBucketVoid_test.cxx
                 INCLUDE_DIRS ${ROOT_INCLUDE_DIRS}
-                LINK_LIBRARIES ${ROOT_LIBRARIES} AthenaKernel CxxUtils SGTools GaudiKernel TestTools AthAllocators AthContainers AthLinks RootUtils RootUtilsPyROOT AthenaPoolCnvSvcLib PersistentDataModel PersistentDataModelTPCnv xAODHIEvent xAODMuon xAODTracking AthenaROOTAccess )
+                LINK_LIBRARIES ${ROOT_LIBRARIES} AthenaKernel SGTools GaudiKernel TestTools AthAllocators AthContainers AthContainersRoot AthLinks RootUtils RootUtilsPyROOT AthenaPoolCnvSvcLib PersistentDataModel PersistentDataModelTPCnv xAODHIEvent xAODMuon xAODTracking AthenaROOTAccess )
 
 # Install files from the package:
 atlas_install_python_modules( python/*.py )
diff --git a/PhysicsAnalysis/AthenaROOTAccess/cmt/requirements b/PhysicsAnalysis/AthenaROOTAccess/cmt/requirements
index b67300ee2bf..b0690688cd6 100755
--- a/PhysicsAnalysis/AthenaROOTAccess/cmt/requirements
+++ b/PhysicsAnalysis/AthenaROOTAccess/cmt/requirements
@@ -11,7 +11,6 @@ author Wim Lavrijsen <WLavrijsen@lbl.gov>
 use AtlasPolicy      AtlasPolicy-*    
 use AtlasROOT        AtlasROOT-*        External
 use GaudiInterface   GaudiInterface-*   External
-use CxxUtils         CxxUtils-*         Control
 use AthenaKernel     AthenaKernel-*     Control
 use SGTools          SGTools-*          Control
 use AthContainersInterfaces AthContainersInterfaces-* Control
@@ -23,6 +22,7 @@ private
 use AthAllocators    AthAllocators-*    Control
 use AthLinks         AthLinks-*         Control
 use AthContainers    AthContainers-*    Control
+use AthContainersRoot AthContainersRoot-* Control
 use RootUtils        RootUtils-*        Control
 use xAODMuon         xAODMuon-*         Event/xAOD
 use xAODTracking     xAODTracking-*     Event/xAOD
diff --git a/PhysicsAnalysis/AthenaROOTAccess/python/dumpers.py b/PhysicsAnalysis/AthenaROOTAccess/python/dumpers.py
index cc372373f45..77d71a3192f 100644
--- a/PhysicsAnalysis/AthenaROOTAccess/python/dumpers.py
+++ b/PhysicsAnalysis/AthenaROOTAccess/python/dumpers.py
@@ -126,7 +126,7 @@ def tree_find_type (dhe, tree):
               dhe.transtype = br.GetClassName()
               break
         if obj:
-            clsname = obj.__class__.__name__
+            clsname = obj.__class__.__cppname__
             if clsname.startswith ('ROOT.'):
                 clsname = clsname[5:]
             dhe.transtype = clsname
@@ -211,7 +211,8 @@ _typedefs = [('AtlasHitsVector<TrackRecord>'  , 'TrackRecordCollection'),
              ('DataVector<xAOD::TrigRNNOutput_v2>','xAOD::TrigRNNOutputContainer_v2'),
              ('DataVector<xAOD::TrigRNNOutput_v2>','xAOD::TrigRNNOutputContainer'),
              ('DataVector<xAOD::TrigRingerRings_v1>','xAOD::TrigRingerRingsContainer_v1'),
-             ('DataVector<xAOD::TrigRingerRings_v1>','xAOD::TrigRingerRingsContainer'),
+             ('DataVector<xAOD::TrigRingerRings_v2>','xAOD::TrigRingerRingsContainer_v2'),
+             ('DataVector<xAOD::TrigRingerRings_v2>','xAOD::TrigRingerRingsContainer'),
              ('DataVector<xAOD::L2CombinedMuon_v1>','xAOD::L2CombinedMuonContainer_v1'),
              ('DataVector<xAOD::L2CombinedMuon_v1>','xAOD::L2CombinedMuonContainer'),
              ('DataVector<xAOD::TrackParticleClusterAssociation_v1>' , 'xAOD::TrackParticleClusterAssociationContainer_v1'),
@@ -228,7 +229,17 @@ _typedefs = [('AtlasHitsVector<TrackRecord>'  , 'TrackRecordCollection'),
              ('DataVector<xAOD::DiTauJet_v1>' , 'xAOD::DiTauJetContainer_v1'),
              ('DataVector<xAOD::TrigPassBits_v1>' , 'xAOD::TrigPassBitsContainer'),
              ('DataVector<xAOD::TrigPassBits_v1>' , 'xAOD::TrigPassBitsContainer_v1'),
+             ('DataVector<xAOD::CaloRings_v1>' , 'xAOD::CaloRingsContainer'),
+             ('DataVector<xAOD::CaloRings_v1>' , 'xAOD::CaloRingsContainer_v1'),
+             ('DataVector<xAOD::RingSet_v1>' ,   'xAOD::RingSetContainer'),
+             ('DataVector<xAOD::RingSet_v1>' ,   'xAOD::RingSetContainer_v1'),
              
+             ('DataVector<xAOD::ForwardEventInfo_v1>' ,'xAOD::ForwardEventInfoContainer'),
+             ('DataVector<xAOD::ForwardEventInfo_v1>' ,'xAOD::ForwardEventInfoContainer_v1'),
+             ('DataVector<xAOD::MBTSModule_v1>' ,'xAOD::MBTSModuleContainer'),
+             ('DataVector<xAOD::MBTSModule_v1>' ,'xAOD::MBTSModuleContainer_v1'),
+             ('DataVector<xAOD::ZdcModule_v1>' , 'xAOD::ZdcModuleContainer'),
+             ('DataVector<xAOD::ZdcModule_v1>' , 'xAOD::ZdcModuleContainer_v1'),
              ('xAOD::MissingETContainer_v1'    , 'xAOD::MissingETContainer'),
              ('xAOD::MissingETComponentMap_v1' , 'xAOD::MissingETComponentMap'),
              ('xAOD::MissingETAssociationMap_v1' , 'xAOD::MissingETAssociationMap'),
diff --git a/PhysicsAnalysis/AthenaROOTAccess/python/transientTree.py b/PhysicsAnalysis/AthenaROOTAccess/python/transientTree.py
index 7e8e130bcc4..05a923a05be 100755
--- a/PhysicsAnalysis/AthenaROOTAccess/python/transientTree.py
+++ b/PhysicsAnalysis/AthenaROOTAccess/python/transientTree.py
@@ -481,7 +481,9 @@ def _handle_elem (elem, file, trans_tree, pers_type, pers_tree, branch_names,
                 trans_type = trans_type2
                 trans_branch_name_suffix = '_auxcnv'
 
-    elif pers_type != trans_type and pers_type.startswith ('DataVector<xAOD::'):
+    elif (pers_type != trans_type and
+          (pers_type.startswith ('DataVector<xAOD::') or
+           pers_type.startswith ('DataVector<DMTest::'))):
        trans_branch_name_suffix = '_auxcnv'
 
     elif (pers_type != trans_type and
diff --git a/PhysicsAnalysis/AthenaROOTAccess/src/AuxStoreARA.cxx b/PhysicsAnalysis/AthenaROOTAccess/src/AuxStoreARA.cxx
index c5857ca8295..80d2b1fee95 100644
--- a/PhysicsAnalysis/AthenaROOTAccess/src/AuxStoreARA.cxx
+++ b/PhysicsAnalysis/AthenaROOTAccess/src/AuxStoreARA.cxx
@@ -16,7 +16,7 @@
 
 
 #include "AuxStoreARA.h"
-#include "RootAuxVectorFactory.h"
+#include "AthContainersRoot/getDynamicAuxID.h"
 #include "AthenaROOTAccess/branchSeek.h"
 #include "AthContainers/tools/error.h"
 
@@ -25,179 +25,35 @@
 
 #include "TROOT.h"
 #include "TBranch.h"
-#include "TLeaf.h"
 #include "TClass.h"
-#include "TClassEdit.h"
-#include "TVirtualCollectionProxy.h"
 
 #include <iostream>
 
-using namespace AthenaROOTAccess;
-using namespace std;
-
-
-namespace {
-
 
-const std::type_info* dataTypeToTypeInfo (EDataType type, std::string& typeName)
-{
-  RootUtils::Type typ (type);
-  typeName = typ.getTypeName();
-  return typ.getTypeInfo();
-}
+using namespace AthenaROOTAccess;
 
 
-/**
- * @brief Given a branch, return the aux data type for that branch.
- * @param br The branch for which we want to get the type.
- * @param standalone Is this for a standalone object?
- * @param[out] elementTypeName Name of the type for one aux data element.
- *                             Same as branchTypeName if @c standalone is true.
- * @param[out] branchTypeName Name of the type for this branch.
- *
- * If standalone is true, then we return the type of the branch
- * directly.  Otherwise, the branch should be a STL vector;
- * we return the type of the vector's payload.
- *
- * Returns 0 on failure.
- */
-const std::type_info* getElementType (TBranch* br,
-                                      bool standalone,
-                                      std::string& elementTypeName,
-                                      std::string& branchTypeName)
+AuxStoreARA::AuxStoreARA(SG::IAuxBranches &container, long long entry, bool standalone)
+  : SG::AuxStoreRoot (container, entry, standalone)
 {
-  TClass* expectedClass = 0;
-  EDataType expectedType = kOther_t;
-  if (br->GetExpectedType (expectedClass, expectedType) != 0) {
-    return 0;
-  }
-
-  if (standalone) {
-    if (expectedClass) {
-      elementTypeName = expectedClass->GetName();
-      branchTypeName = elementTypeName;
-      return expectedClass->GetTypeInfo();
-    }
-    const std::type_info* ret = dataTypeToTypeInfo (expectedType,
-                                                    elementTypeName);
-    branchTypeName = elementTypeName;
-    return ret;
-  }
-
-  // Not standalone; branch should be a vector.
-  if (!expectedClass) return 0;
-
-  branchTypeName = expectedClass->GetName();
-  if (strncmp (expectedClass->GetName(), "vector<", 7) == 0) {
-    TVirtualCollectionProxy* prox = expectedClass->GetCollectionProxy();
-    if (!prox) return 0;
-    if (prox->GetValueClass()) {
-      elementTypeName = prox->GetValueClass()->GetName();
-      return prox->GetValueClass()->GetTypeInfo();
-    }
-    return dataTypeToTypeInfo (prox->GetType(), elementTypeName);
-  }
-  else if (strncmp (expectedClass->GetName(), "SG::PackedContainer<", 20) == 0){
-    TClassEdit::TSplitType split (expectedClass->GetName());
-    if (split.fElements.size() > 1) {
-      elementTypeName = split.fElements[1];
-      RootUtils::Type typ (elementTypeName);
-      return typ.getTypeInfo();
-    }
-  }
-  return 0;
+  fillAuxIDs();
 }
 
 
-// Convert from class name to TClass; try to avoid autoparsing.
-TClass* getClassIfDictionaryExists (const std::string& cname)
+SG::auxid_t AuxStoreARA::resolveAuxID (SG::IAuxBranches& /*container*/,
+                                       const std::type_info* ti,
+                                       const std::string& name,
+                                       const std::string& elem_type_name,
+                                       const std::string& branch_type_name)
 {
-  if (TClass* cl = (TClass*)gROOT->GetListOfClasses()->FindObject(cname.c_str())) {
-    if (cl->IsLoaded() && cl->HasDictionary()) return cl;
-    return nullptr;
-  }
-
-  if (gInterpreter->GetClassSharedLibs (cname.c_str())) {
-    TClass* cl = TClass::GetClass (cname.c_str());
-    if (cl->HasDictionary())
-      return cl;
+  if (!ti) {
+    SG::AuxTypeRegistry& r = SG::AuxTypeRegistry::instance();
+    return r.findAuxID(name);
   }
-  return nullptr;
-}
-
-
-} // Anonymous namespace
-
-
-AuxStoreARA::AuxStoreARA(IAuxBranches &container, long long entry, bool standalone)
-  : SG::AuxStoreInternal (standalone),
-    m_entry(entry), m_container(container)
-{
-   SG::AuxTypeRegistry& r = SG::AuxTypeRegistry::instance();
-   for( const auto& attr2branch: m_container.auxBranches() ) {
-      const string& attr = attr2branch.first;
-      std::string elemen_type_name;
-      std::string branch_type_name;
-      const std::type_info* ti = getElementType(attr2branch.second,
-                                                standalone,
-                                                elemen_type_name,
-                                                branch_type_name);
-      SG::auxid_t auxid;
-      if (!ti)
-        auxid = r.findAuxID(attr);
-      else {
-        auxid = r.getAuxID(*ti, attr);
-
-        if (auxid == SG::null_auxid) {
-          std::string fac_class_name = "SG::AuxTypeVectorFactory<" +
-            elemen_type_name;
-          if (fac_class_name[fac_class_name.size()-1] == '>')
-            fac_class_name += ' ';
-          fac_class_name += '>';
-          TClass* fac_class = getClassIfDictionaryExists (fac_class_name);
-          if (fac_class)
-          {
-            TClass* base_class = getClassIfDictionaryExists ("SG::IAuxTypeVectorFactory");
-            if (base_class) {
-              int offs = fac_class->GetBaseClassOffset (base_class);
-              if (offs >= 0) {
-                void* fac_vp = fac_class->New();
-                if (fac_vp) {
-                  SG::IAuxTypeVectorFactory* fac = reinterpret_cast<SG::IAuxTypeVectorFactory*> (reinterpret_cast<unsigned long>(fac_vp) + offs);
-                  r.addFactory (*ti, fac);
-                  auxid = r.getAuxID(*ti, attr);
-                }
-              }
-            }
-          }
-        }
-
-        if (auxid == SG::null_auxid) {
-          std::string vec_name = branch_type_name;
-          if (standalone) {
-            vec_name = "std::vector<" + branch_type_name;
-            if (vec_name[vec_name.size()-1] == '>')
-              vec_name += " ";
-            vec_name += ">";
-          }
-          TClass* vec_class = TClass::GetClass (branch_type_name.c_str());
-
-          if (vec_class) {
-            SG::IAuxTypeVectorFactory* fac = new RootAuxVectorFactory (vec_class);
-            r.addFactory (*ti, fac);
-            auxid = r.getAuxID(*ti, attr);
-          }
-        }
-
-      }
-      // add AuxID to the list
-      // May still be null if we don't have a dictionary for the branch.
-      if (auxid != SG::null_auxid)
-        addAuxID (auxid);
-   }
-
-   //lock();
-}
+  return SG::getDynamicAuxID (*ti, name,
+                              elem_type_name, branch_type_name,
+                              standalone());
+ }
 
 
 AuxStoreARA::~AuxStoreARA()
@@ -209,79 +65,19 @@ AuxStoreARA::~AuxStoreARA()
 
 void AuxStoreARA::GetEntry (long long entry)
 {
-  m_entry = entry;
+  setEntry (entry);
   for (TBranch* br : m_branches)
     branchSeek (br, entry);
 }
 
 
-const void* AuxStoreARA::getData(SG::auxid_t auxid) const
-{
-  guard_t guard (m_mutex);
-  // lock
-  const void* ret = SG::AuxStoreInternal::getData (auxid);
-  if (!ret) {
-    const_cast<AuxStoreARA*>(this)->readData(auxid);
-    ret = SG::AuxStoreInternal::getData (auxid);
-  }
-  return ret;
-}
-
-
-const void* AuxStoreARA::getIOData(SG::auxid_t auxid) const
-{
-  guard_t guard (m_mutex);
-  const void* ret = SG::AuxStoreInternal::getIODataInternal (auxid, true);
-  if (!ret) {
-    const_cast<AuxStoreARA*>(this)->readData(auxid);
-    ret = SG::AuxStoreInternal::getIOData (auxid);
-  }
-  return ret;
-}
-
-
-bool AuxStoreARA::readData(SG::auxid_t auxid)
+bool AuxStoreARA::doReadData (SG::IAuxBranches& container,
+                              SG::auxid_t /*auxid*/,
+                              TBranch& branch,
+                              TClass* cl,
+                              void* vector,
+                              long long entry)
 {
-   //cout << "AuxStoreAPR::getData() id=" << auxid << ",  name="
-   //     << reg.getName(auxid) << ", container=" << m_container.m_branchName << endl;
-
-   TBranch* branch = m_container.findAuxBranch(auxid);
-   // check if there is a branch in the file
-   if( !branch ) return false; 
-   // cout << " Branch: name=" << branch->GetName() << ",  class name=" << branch->GetClassName() << endl;
-
-   TClass*      cl = 0;
-
-   if( standalone() ) {
-      // get TClass for untyped and standalone storage 
-      EDataType    typ;
-      if( branch->GetExpectedType(cl, typ) ) {
-         ATHCONTAINERS_ERROR("AuxStoreAPR::getData", string("Error getting branch type for ") + branch->GetName() );
-         return false;
-      }
-   }
-
-   auto readAuxBranch = [&](void *p) {
-     if( m_container.readAuxBranch(*branch, p, m_entry).isSuccess() ) {
-       m_branches.push_back (branch);
-       return true;
-     }
-     ATHCONTAINERS_ERROR("AuxStoreAPR::getData", string("Error reading branch ") + branch->GetName() );
-     return false;
-   };
-
-   void *       vector = 0;
-
-   // Make a 1-element vector.
-   SG::AuxStoreInternal::getDataInternal(auxid, 1, 1, true);
-   if (!standalone()) {
-     EDataType typ;
-     branch->GetExpectedType(cl, typ);
-     if (cl && strncmp (cl->GetName(), "SG::PackedContainer<", 20) == 0)
-       setOption (auxid, SG::AuxDataOption ("nbits", 32));
-   }
-   vector = const_cast<void*>(SG::AuxStoreInternal::getIOData (auxid)); // xxx
-
    void* data;
 
    if (standalone() && !cl)
@@ -291,37 +87,11 @@ bool AuxStoreARA::readData(SG::auxid_t auxid)
      data = &m_ptrs.back();
    }
 
-   // read branch
-   return readAuxBranch(data);
-}
-
-
-/**
- * @brief Return the data vector for one aux data decoration item.
- * @param auxid The identifier of the desired aux data item.
- * @param size The current size of the container (in case the data item
- *             does not already exist).
- * @param capacity The current capacity of the container (in case
- *                 the data item does not already exist).
- *
- * Each aux data item is stored as a vector, with one entry
- * per entry in the owning container.  This returns a pointer
- * to the start of the vector.
- *
- * The base class implementation works except for the case where we have
- * not yet created a vector for an item in the root file.  We need to 
- * detect that case and raise an exception.
- */
-void*
-AuxStoreARA::getDecoration (SG::auxid_t auxid, size_t size, size_t capacity)
-{
-  guard_t guard (m_mutex);
-  if (SG::AuxStoreInternal::getIODataInternal (auxid, true) == 0 &&
-      SG::AuxStoreInternal::getAuxIDs().count (auxid) > 0)
-  {
-    throw SG::ExcStoreLocked (auxid);
+   if( container.readAuxBranch(branch, data, entry).isSuccess() ) {
+    m_branches.push_back (&branch);
+    return true;
   }
-  return SG::AuxStoreInternal::getDecoration (auxid, size, capacity);
-}
-
 
+  ATHCONTAINERS_ERROR("AuxStoreAPR::doReadData", std::string("Error reading branch ") + branch.GetName() );
+  return false;
+}
diff --git a/PhysicsAnalysis/AthenaROOTAccess/src/AuxStoreARA.h b/PhysicsAnalysis/AthenaROOTAccess/src/AuxStoreARA.h
index ae046ff922c..4c2f716a4f5 100644
--- a/PhysicsAnalysis/AthenaROOTAccess/src/AuxStoreARA.h
+++ b/PhysicsAnalysis/AthenaROOTAccess/src/AuxStoreARA.h
@@ -19,14 +19,12 @@
 #ifndef ATHENAROOTACCESS_AUXSTOREARA
 #define ATHENAROOTACCESS_AUXSTOREARA
 
-#include "AthContainers/AuxStoreInternal.h" 
-#include "AthenaROOTAccess/IAuxBranches.h"
+#include "AthContainersRoot/AuxStoreRoot.h" 
+#include "AthContainersRoot/IAuxBranches.h"
 
 #include "AthContainersInterfaces/IAuxTypeVector.h"
-#include <stdexcept>
 #include <vector>
 #include <list>
-
 #include "TClass.h"
 class TBranch;
 
@@ -34,66 +32,38 @@ class TBranch;
 namespace AthenaROOTAccess {
 
 
-  /**
-   * @brief Aux store implementation to manage dynamic aux variables.
-   */
-  class AuxStoreARA : public SG::AuxStoreInternal
-  {
-  public:
-     AuxStoreARA(IAuxBranches &container, long long entry, bool standalone=false);
-     virtual ~AuxStoreARA() override;
-
-     void GetEntry (long long entry);
-     void SetEntry (long long entry) { m_entry = entry; }
-
-     /// implementation of the IAuxStore interface
-     virtual const void*                getData(SG::auxid_t auxid) const override;
-     virtual void*                      getData(SG::auxid_t auxid, size_t size, size_t capacity) override;
-
-     ///  implementation of the IAuxStoreIO interface
-     virtual const void*                getIOData(SG::auxid_t auxid) const override;
-
-
-     /**
-      * @brief Return the data vector for one aux data decoration item.
-      * @param auxid The identifier of the desired aux data item.
-      * @param size The current size of the container (in case the data item
-      *             does not already exist).
-      * @param capacity The current capacity of the container (in case
-      *                 the data item does not already exist).
-      */
-     virtual void* getDecoration (SG::auxid_t auxid, size_t size, size_t capacity) override;
-
-    
-  protected:
-     /// read data from ROOT and store it in m_vecs. Returns False on error
-     bool readData(SG::auxid_t auxid);
-     
-  protected:
-     long long          m_entry;
-     IAuxBranches      &m_container;
-
-
-   private:
-     std::list<void*> m_ptrs;
-     std::vector<TBranch*> m_branches;
-
-     /// Mutex used to synchronize modifications to the cache vector.
-     typedef AthContainers_detail::mutex mutex_t;
-     typedef AthContainers_detail::lock_guard<mutex_t> guard_t;
-     mutable mutex_t m_mutex;
-   };
-
-  
-
-   inline
-   void* AuxStoreARA::getData(SG::auxid_t auxid, size_t /*size*/, size_t /*capacity*/)
-   {
-      // MN:  how do we add new attributes to this store? A:for now we don't
-      return const_cast<void*>(getData(auxid));
-   }
-
-}   
+/**
+ * @brief Aux store implementation to manage dynamic aux variables.
+ */
+class AuxStoreARA : public SG::AuxStoreRoot
+{
+public:
+  AuxStoreARA(SG::IAuxBranches &container, long long entry, bool standalone=false);
+  virtual ~AuxStoreARA() override;
+
+  void GetEntry (long long entry);
+  void SetEntry (long long entry) { setEntry (entry); }
+
+  virtual SG::auxid_t resolveAuxID (SG::IAuxBranches& container,
+                                    const std::type_info* ti,
+                                    const std::string& name,
+                                    const std::string& elem_type_name,
+                                    const std::string& branch_type_name) override;
+
+  virtual bool doReadData (SG::IAuxBranches& container,
+                           SG::auxid_t auxid,
+                           TBranch& branch,
+                           TClass* cl,
+                           void* vector,
+                           long long entry) override;
+
+private:
+  std::list<void*> m_ptrs;
+  std::vector<TBranch*> m_branches;
+};
+
+
+} // namespace AthenaROOTAccess
 
 #endif
 
diff --git a/PhysicsAnalysis/AthenaROOTAccess/src/ProxyMap.cxx b/PhysicsAnalysis/AthenaROOTAccess/src/ProxyMap.cxx
index 06be7521ed8..1d545b77724 100755
--- a/PhysicsAnalysis/AthenaROOTAccess/src/ProxyMap.cxx
+++ b/PhysicsAnalysis/AthenaROOTAccess/src/ProxyMap.cxx
@@ -54,7 +54,7 @@ ProxyMap::payload_t ProxyMap::s_invalid_data;
 ProxyMap::ProxyMap (AthenaROOTAccess::TTreeBranchMap* trans_tree,
                     TTree* pers_tree)
   : m_trans_tree (trans_tree),
-    m_trans_tree_dict (dynamic_cast<IProxyDictWithPool*> (trans_tree)),
+    m_trans_tree_dict (dynamic_cast<IProxyDict*> (trans_tree)),
     m_pers_tree (pers_tree),
     m_dh_br (0),
     m_dh_ver (0),
diff --git a/PhysicsAnalysis/AthenaROOTAccess/src/RootAuxVectorFactory.cxx b/PhysicsAnalysis/AthenaROOTAccess/src/RootAuxVectorFactory.cxx
deleted file mode 100644
index 0a61b06336d..00000000000
--- a/PhysicsAnalysis/AthenaROOTAccess/src/RootAuxVectorFactory.cxx
+++ /dev/null
@@ -1,372 +0,0 @@
-/*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
-*/
-
-// $Id$
-/**
- * @file AthenaROOTAccess/src/RootAuxVectorFactory.cxx
- * @author scott snyder <snyder@bnl.gov>
- * @date May, 2014
- * @brief Dynamic implementation of @c IAuxVectorFactory,
- *        relying on root vector proxy.
- */
-
-
-#include "RootAuxVectorFactory.h"
-#include "AthContainers/tools/error.h"
-#include "TClass.h"
-#include "TVirtualCollectionProxy.h"
-#include "TROOT.h"
-#include <iostream>
-#include <stdexcept>
-
-
-namespace AthenaROOTAccess {
-
-
-/**
- * @brief Find the vector type associated with @c CL by looking
- *        up the @c vector_type typedef.
- * @param cl The class for which to find the associated vector type.
- *
- * Given type CL, looks for a typedef CL::vector_type and returns the TClass
- * for that if found.  Works for, eg, SG::PackedContainer.
- */
-TClass* lookupVectorType (TClass *cl)
-{
-  std::string tname = cl->GetName();
-  tname += "::vector_type";
-  TDataType* typ = gROOT->GetType (tname.c_str());
-  if (typ)
-    return TClass::GetClass (typ->GetFullTypeName());
-  return nullptr;
-}
-
-
-/**
- * @brief Constructor.  Makes a new vector.
- * @param factory The factory object for this type.
- * @param size Initial size of the new vector.
- * @param capacity Initial capacity of the new vector.
- */
-RootAuxVector::RootAuxVector (const RootAuxVectorFactory* factory,
-                              size_t size, size_t /*capacity*/)
-  : m_factory (factory)
-{
-  TClass* vecClass = factory->vecClass();
-  m_proxy = vecClass->GetCollectionProxy();
-  m_obj = factory->objClass()->New ();
-  m_vec = reinterpret_cast<char*> (m_obj) + factory->offset();
-  this->resize (size);
-}
-
-
-/**
- * @brief Copy constructor.
- * @param other The vector to copy.
- */
-RootAuxVector::RootAuxVector (const RootAuxVector& other)
-  : m_factory (other.m_factory),
-    m_proxy (other.m_proxy)
-{
-  m_obj = m_factory->objClass()->New ();
-  m_vec = reinterpret_cast<char*> (m_obj) + m_factory->offset();
-  size_t sz = other.size();
-  this->resize (sz);
-
-  if (sz > 0) {
-    const RootUtils::Type& rootType = m_factory->rootType();
-
-    const void* otherPtr = 0;
-    {
-      TVirtualCollectionProxy::TPushPop bind (m_proxy, other.m_vec);
-      otherPtr = m_proxy->At(0);
-    }
-    
-    rootType.copyRange (this->toPtr(), otherPtr, sz);
-  }
-}
-
-
-/**
- * @brief Destructor.
- *
- * This will free the vector data.
- */
-RootAuxVector::~RootAuxVector()
-{
-  m_factory->objClass()->Destructor (m_obj);
-}
-
-
-/**
- * @brief Make a copy of this vector.
- */
-SG::IAuxTypeVector* RootAuxVector::clone() const
-{
-  return new RootAuxVector (*this);
-}
-
-
-/**
- * @brief Return a pointer to the start of the vector's data.
- */
-void* RootAuxVector::toPtr ()
-{
-  TVirtualCollectionProxy::TPushPop bind (m_proxy, m_vec);
-  if (m_proxy->Size() == 0)
-    return 0;
-  return m_proxy->At(0);
-}
-
-
-/**
- * @brief Return a pointer to the overall object.
- */
-void* RootAuxVector::toVector ()
-{
-  return m_obj;
-}
-
-
-/**
- * @brief Return the size of the vector.
- */
-size_t RootAuxVector::size() const
-{
-  TVirtualCollectionProxy::TPushPop bind (m_proxy, m_vec);
-  return m_proxy->Size();
-}
-
-
-/**
- * @brief Change the size of the vector.
- * @param sz The new vector size.
- */
-void RootAuxVector::resize (size_t sz)
-{
-  TVirtualCollectionProxy::TPushPop bind (m_proxy, m_vec);
-  m_proxy->Allocate(sz, false);
-}
-
-
-/**
- * @brief Change the capacity of the vector.
- * @param sz The new vector capacity.
- */
-void RootAuxVector::reserve (size_t /*sz*/)
-{
-}
-
-
-/**
- * @brief Shift the elements of the vector.
- * @param pos The starting index for the shift.
- * @param offs The (signed) amount of the shift.
- *
- * This operation shifts the elements in the vectors for all
- * aux data items, to implement an insertion or deletion.
- * @c offs may be either positive or negative.
- *
- * If @c offs is positive, then the container is growing.
- * The container size should be increased by @c offs,
- * the element at @c pos moved to @c pos + @c offs,
- * and similarly for following elements.
- * The elements between @c pos and @c pos + @c offs should
- * be default-initialized.
- *
- * If @c offs is negative, then the container is shrinking.
- * The element at @c pos should be moved to @c pos + @c offs,
- * and similarly for following elements.
- * The container should then be shrunk by @c -offs elements
- * (running destructors as appropriate).
- */
-void RootAuxVector::shift (size_t pos, ptrdiff_t offs)
-{
-  TVirtualCollectionProxy::TPushPop bind (m_proxy, m_vec);
-  size_t eltsz = m_proxy->GetIncrement();
-
-  const RootUtils::Type& rootType = m_factory->rootType();
-
-  if (offs < 0) {
-    if (-offs > static_cast<ptrdiff_t>(pos)) offs = -pos;
-    char* beg = reinterpret_cast<char*>(m_proxy->At(0));
-    rootType.copyRange (beg + eltsz*(pos+offs),
-                        beg + eltsz*pos,
-                        m_proxy->Size() - pos);
-    m_proxy->Allocate (m_proxy->Size() + offs, false);
-  }
-  else if (offs > 0) {
-    size_t oldsz = m_proxy->Size();
-    m_proxy->Allocate (oldsz + offs, false);
-    char* beg = reinterpret_cast<char*>(m_proxy->At(0));
-    rootType.copyRange (beg + eltsz*(pos+offs),
-                        beg + eltsz*pos,
-                        m_proxy->Size() - pos - offs);
-    rootType.clearRange (beg + eltsz*pos, offs);
-  }
-}
-
-
-/**
- * @brief Return the type of the complete object to be saved.
- *
- * For example, if the object is a @c std::vector, then we return
- * the @c type_info of the vector.  But if we're holding
- * a @c PackedContainer, then we return the @c type_info of the
- * @c PackedContainer.
- *
- * Can return null if the operation is not supported.  In that case,
- * I/O will use the type found from the variable registry.
- */
-const std::type_info* RootAuxVector::objType() const
-{
-  return m_factory->objClass()->GetTypeInfo();
-}
-
-
-//==================================================================
-
-
-/**
- * @brief Constructor.
- * @param vecClass The @c TClass for the vector object.
- */
-RootAuxVectorFactory::RootAuxVectorFactory (TClass* objClass)
-  : m_objClass (objClass),
-    m_vecClass (objClass),
-    m_offset (0)
-{
-  TVirtualCollectionProxy* proxy = m_vecClass->GetCollectionProxy();
-
-  if (!proxy) {
-    TClass* vecClass = lookupVectorType (objClass);
-    if (vecClass) {
-      m_vecClass = vecClass;
-      Int_t offs = objClass->GetBaseClassOffset (vecClass);
-      if (offs >= 0) {
-        m_offset = offs;
-        proxy = vecClass->GetCollectionProxy();
-      }
-      else {
-        ATHCONTAINERS_ERROR("RootAuxVectorFactory::RootAuxVectorFactory",
-                            std::string("Can't find vector base class in ") +
-                            objClass->GetName());
-      }
-    }
-  }
-
-  if (!proxy) {
-    std::string err = "Can't find collection proxy for ";
-    err += m_vecClass->GetName();
-    throw std::runtime_error (err.c_str());
-  }
-
-  if (m_vecClass->GetTypeInfo() == 0) {
-    ATHCONTAINERS_ERROR("RootAuxVectorFactory::RootAuxVectorFactory",
-                        std::string("No type_info available for class ") +
-                        m_vecClass->GetName() +
-                        std::string(".  There is probably a missing dictionary.  We will likely crash further on."));
-  }
-
-  TClass* eltClass = proxy->GetValueClass();
-  if (eltClass)
-    m_type.init (eltClass);
-  else
-    m_type.init (proxy->GetType());
-}
-
-
-/**
- * @brief Destructor.
- */
-RootAuxVectorFactory::~RootAuxVectorFactory()
-{
-}
-
-
-/**
- * @brief Create a vector object of this type.
- * @param size Initial size of the new vector.
- * @param capacity Initial capacity of the new vector.
- */
-SG::IAuxTypeVector*
-RootAuxVectorFactory::create (size_t size, size_t capacity) const
-{
-  return new RootAuxVector (this, size, capacity);
-}
-
-
-/**
- * @brief Copy an element between vectors.
- * @param dst Pointer to the start of the destination vector's data.
- * @param dst_index Index of destination element in the vector.
- * @param src Pointer to the start of the source vector's data.
- * @param src_index Index of source element in the vector.
- *
- * @c dst and @ src can be either the same or different.
- */
-void RootAuxVectorFactory::copy (void* dst,        size_t dst_index,
-                                 const void* src,  size_t src_index) const
-{
-  m_type.assign (dst, dst_index, src, src_index);
-}
-
-
-/**
- * @brief Swap an element between vectors.
- * @param a Pointer to the start of the first vector's data.
- * @param aindex Index of the element in the first vector.
- * @param b Pointer to the start of the second vector's data.
- * @param bindex Index of the element in the second vector.
- *
- * @c a and @ b can be either the same or different.
- */
-void RootAuxVectorFactory::swap (void* a, size_t aindex,
-                                 void* b, size_t bindex) const
-{
-  m_type.swap (a, aindex, b, bindex);
-}
-
-
-/**
- * @brief Clear an element within a vector (static method).
- * @param dst Pointer to the start of the vector's data.
- * @param dst_index Index of the element in the vector.
- */
-void RootAuxVectorFactory::clear (void* dst, size_t dst_index) const
-{
-  m_type.clear (dst, dst_index);
-}
-
-
-/**
- * @brief Return the size of an element of this vector type.
- */
-size_t RootAuxVectorFactory::getEltSize() const
-{
-  return m_type.getSize();
-}
-
-
-/**
- * @brief Return the @c type_info of the overall object.
- */
-const std::type_info* RootAuxVectorFactory::tiVec() const
-{
-  return m_objClass->GetTypeInfo();
-}
-
-
-/**
- * @brief True if the vectors created by this factory work by dynamic
- *        emulation (via @c TVirtualCollectionProxy or similar); false
- *        if the std::vector code is used directly.
- */
-bool RootAuxVectorFactory::isDynamic() const
-{
-  return true;
-}
-
-
-} // namespace AthenaROOTAccess
diff --git a/PhysicsAnalysis/AthenaROOTAccess/src/RootAuxVectorFactory.h b/PhysicsAnalysis/AthenaROOTAccess/src/RootAuxVectorFactory.h
deleted file mode 100644
index c2b56018583..00000000000
--- a/PhysicsAnalysis/AthenaROOTAccess/src/RootAuxVectorFactory.h
+++ /dev/null
@@ -1,318 +0,0 @@
-// This file's extension implies that it's C, but it's really -*- C++ -*-.
-
-/*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
-*/
-
-// $Id$
-/**
- * @file RootAuxVectorFactory.h
- * @author scott snyder <snyder@bnl.gov>
- * @date May, 2014
- * @brief Dynamic implementation of @c IAuxVectorFactory,
- *        relying on root's vector proxy.
- *
- * This is basically the same as the corresponding class in RootStorageSvc.
- * Duplicated here due to the lack of any suitable common packages
- * with the correct dependencies.
- */
-
-
-#ifndef ATHENAROOTACCESS_ROOTAUXVECTORFACTORY_H
-#define ATHENAROOTACCESS_ROOTAUXVECTORFACTORY_H
-
-
-#include "AthContainersInterfaces/IAuxTypeVectorFactory.h"
-#include "AthContainersInterfaces/IAuxTypeVector.h"
-#include "RootUtils/Type.h"
-
-
-class TClass;
-class TVirtualCollectionProxy;
-
-
-namespace AthenaROOTAccess {
-
-
-class RootAuxVectorFactory;
-
-
-/**
- * @brief Dynamic implementation of @c IAuxTypeVector,
- *        relying on root vector proxy.
- *
- * This is used for the case when we need to manipulate an aux data vector
- * present in an input data file but we have neither a proper template
- * instantiation for the factory (because the variable was never explicitly
- * referenced), nor can we find a dictionary entry for the factory.j
- *
- * This implementation works by relying entirely on the root
- * dictionary information.
- */
-class RootAuxVector
-  : public SG::IAuxTypeVector
-{
-public:
-  /**
-   * @brief Constructor.  Makes a new vector.
-   * @param factory The factory object for this type.
-   * @param size Initial size of the new vector.
-   * @param capacity Initial capacity of the new vector.
-   */
-  RootAuxVector (const RootAuxVectorFactory* factory,
-                 size_t size,
-                 size_t capacity);
-
-
-  /**
-   * @brief Copy constructor.
-   * @param other The vector to copy.
-   */
-  RootAuxVector (const RootAuxVector& other);
-
-
-  // Disallow assignment.
-  RootAuxVector& operator= (const RootAuxVector&) = delete;
-
-
-  /**
-   * @brief Destructor.
-   *
-   * This will free the vector data.
-   */
-  virtual ~RootAuxVector() override;
-
-
-  /**
-   * @brief Make a copy of this vector.
-   */
-  virtual SG::IAuxTypeVector* clone() const override;
-
-
-  /**
-   * @brief Return a pointer to the start of the vector's data.
-   */
-  virtual void* toPtr() override;
-
-
-  /**
-   * @brief Return a pointer to the overall object.
-   */
-  virtual void* toVector() override;
-
-
-
-  /**
-   * @brief Return the size of the vector.
-   */
-  virtual size_t size() const override;
-
-
-  /**
-   * @brief Change the size of the vector.
-   * @param sz The new vector size.
-   */
-  virtual void resize (size_t sz) override;
-
-
-  /**
-   * @brief Change the capacity of the vector.
-   * @param sz The new vector capacity.
-   */
-  virtual void reserve (size_t sz) override;
-
-
-  /**
-   * @brief Shift the elements of the vector.
-   * @param pos The starting index for the shift.
-   * @param offs The (signed) amount of the shift.
-   *
-   * This operation shifts the elements in the vectors for all
-   * aux data items, to implement an insertion or deletion.
-   * @c offs may be either positive or negative.
-   *
-   * If @c offs is positive, then the container is growing.
-   * The container size should be increased by @c offs,
-   * the element at @c pos moved to @c pos + @c offs,
-   * and similarly for following elements.
-   * The elements between @c pos and @c pos + @c offs should
-   * be default-initialized.
-   *
-   * If @c offs is negative, then the container is shrinking.
-   * The element at @c pos should be moved to @c pos + @c offs,
-   * and similarly for following elements.
-   * The container should then be shrunk by @c -offs elements
-   * (running destructors as appropriate).
-   */
-  virtual void shift (size_t pos, ptrdiff_t offs) override;
-
-
-  /**
-   * @brief Return the type of the complete object to be saved.
-   *
-   * For example, if the object is a @c std::vector, then we return
-   * the @c type_info of the vector.  But if we're holding
-   * a @c PackedContainer, then we return the @c type_info of the
-   * @c PackedContainer.
-   *
-   * Can return null if the operation is not supported.  In that case,
-   * I/O will use the type found from the variable registry.
-   */
-  virtual const std::type_info* objType() const override;
-
-
-private:
-  /// Pointer back to the factory class for this type.
-  const RootAuxVectorFactory* m_factory;
-
-  /// The collection proxy for the vector.
-  TVirtualCollectionProxy* m_proxy;
-
-  /// Pointer to the overall object itself.
-  void* m_obj;
-
-  /// Pointer to the vector object itself.
-  void* m_vec;
-};
-
-
-/**
- * @brief Dynamic implementation of @c IAuxVectorFactory,
- *        relying on root's vector proxy.
- *
- * This is used for the case when we need to manipulate an aux data vector
- * present in an input data file but we have neither a proper template
- * instantiation for the factory (because the variable was never explicitly
- * referenced), nor can we find a dictionary entry for the factory.j
- *
- * This implementation works by relying entirely on the root
- * dictionary information.
- *
- * We may either be dealing directly with an STL vector class, or with
- * embedded in another class (as for PackedContainer).  Here, @a vecClass
- * is the class of the STL vector and @a objClass is the overall object
- * class.  In the case of a direct STL vector, these are identical.
- */
-class RootAuxVectorFactory
-  : public SG::IAuxTypeVectorFactory
-{
-public:
-  /**
-   * @brief Constructor.
-   * @param vecClass The @c TClass for the vector object.
-   */
-  RootAuxVectorFactory (TClass* objClass);
-
-
-  /**
-   * @brief Destructor.
-   */
-  virtual ~RootAuxVectorFactory() override;
-
-
-  /**
-   * @brief Return the ROOT type wrapper.
-   */
-  const RootUtils::Type& rootType() const { return m_type; }
-
-
-  /**
-   * @brief Return the @c TClass for the overall object.
-   */
-  TClass* objClass() const { return m_objClass; }
-
-
-  /**
-   * @brief Return the @c TClass for the @c std::vector.
-   */
-  TClass* vecClass() const { return m_vecClass; }
-
-
-  /**
-   * @brief Return the offset of the vector within the object.
-   */
-  size_t offset() const { return m_offset; }
-
-
-  /**
-   * @brief Create a vector object of this type.
-   * @param size Initial size of the new vector.
-   * @param capacity Initial capacity of the new vector.
-   */
-  virtual SG::IAuxTypeVector* create (size_t size, size_t capacity) const
-    override;
-
-
-  /**
-   * @brief Copy an element between vectors.
-   * @param dst Pointer to the start of the destination vector's data.
-   * @param dst_index Index of destination element in the vector.
-   * @param src Pointer to the start of the source vector's data.
-   * @param src_index Index of source element in the vector.
-   *
-   * @c dst and @ src can be either the same or different.
-   */
-  virtual void copy (void* dst,        size_t dst_index,
-                     const void* src,  size_t src_index) const override;
-
-
-  /**
-   * @brief Swap an element between vectors.
-   * @param a Pointer to the start of the first vector's data.
-   * @param aindex Index of the element in the first vector.
-   * @param b Pointer to the start of the second vector's data.
-   * @param bindex Index of the element in the second vector.
-   *
-   * @c a and @ b can be either the same or different.
-   */
-  virtual void swap (void* a, size_t aindex,
-                     void* b, size_t bindex) const override;
-
-
-  /**
-   * @brief Clear an element within a vector (static method).
-   * @param dst Pointer to the start of the vector's data.
-   * @param dst_index Index of the element in the vector.
-   */
-  virtual void clear (void* dst, size_t dst_index) const override;
-
-
-  /**
-   * @brief Return the size of an element of this vector type.
-   */
-  virtual size_t getEltSize() const override;
-
-
-  /**
-   * @brief Return the @c type_info of the overall object.
-   */
-  virtual const std::type_info* tiVec() const override;
-
-
-  /**
-   * @brief True if the vectors created by this factory work by dynamic
-   *        emulation (via @c TVirtualCollectionProxy or similar); false
-   *        if the std::vector code is used directly.
-   */
-  virtual bool isDynamic() const override;
-
-
-private:
-  /// The @c TClass for the overall object.
-  TClass* m_objClass;
-
-  /// The @c TClass for the std::vector.
-  TClass* m_vecClass;
-
-  /// Offset of the STL vector within the overall object.
-  size_t m_offset;
-
-  /// Wrapper for the ROOT type of the element.
-  RootUtils::Type m_type;
-};
-
-
-} // namespace AthenaROOTAccess
-
-
-#endif // not ATHENAROOTACCESS_ROOTAUXVECTORFACTORY_H
diff --git a/PhysicsAnalysis/AthenaROOTAccess/src/TBranchAlias.cxx b/PhysicsAnalysis/AthenaROOTAccess/src/TBranchAlias.cxx
index bac0aed561f..16c716bd7a4 100644
--- a/PhysicsAnalysis/AthenaROOTAccess/src/TBranchAlias.cxx
+++ b/PhysicsAnalysis/AthenaROOTAccess/src/TBranchAlias.cxx
@@ -638,7 +638,13 @@ void TBranchAlias::setStore (bool clear, long long entry)
 }
 
 
-std::vector<IAuxBranches::auxpair_t> TBranchAlias::auxBranches() const
+const std::string& TBranchAlias::getName() const
+{
+  return m_targ_branchname;
+}
+
+
+std::vector<SG::IAuxBranches::auxpair_t> TBranchAlias::auxBranches() const
 {
   std::vector<IAuxBranches::auxpair_t> out;
   TTree* tree = m_targ_tree;
@@ -658,7 +664,7 @@ std::vector<IAuxBranches::auxpair_t> TBranchAlias::auxBranches() const
 }
 
 
-TBranch* TBranchAlias::findAuxBranch (SG::auxid_t auxid) const
+TBranch* TBranchAlias::findAuxBranch (SG::auxid_t auxid)
 {
   auto abr_it = m_dyn_branch_map.find(auxid);
   if( abr_it != m_dyn_branch_map.end() ) {
@@ -696,6 +702,12 @@ StatusCode TBranchAlias::readAuxBranch (TBranch& br, void* p, long long entry)
 }
 
 
+StatusCode TBranchAlias::readAuxBranch (TBranch&, void*, const std::type_info&, long long)
+{
+  std::abort();
+}
+
+
 /**
  * @brief Set a fixup to be run on this branch after GetEntry.
  * @param fixup The fixup to run.  (Ownership is not transferred.)
diff --git a/PhysicsAnalysis/AthenaROOTAccess/src/TTreeTrans.cxx b/PhysicsAnalysis/AthenaROOTAccess/src/TTreeTrans.cxx
index b34835fa948..54fee4a948b 100644
--- a/PhysicsAnalysis/AthenaROOTAccess/src/TTreeTrans.cxx
+++ b/PhysicsAnalysis/AthenaROOTAccess/src/TTreeTrans.cxx
@@ -179,7 +179,7 @@ void TTreeTrans::resetBranch (sgkey_t sgkey)
  * The current tree is the one which gets installed as the source
  * when @c ElementLink's are constructed.
  */
-IProxyDictWithPool* TTreeTrans::setCurTree (IProxyDictWithPool* tree)
+IProxyDict* TTreeTrans::setCurTree (IProxyDict* tree)
 {
   return SG::CurrentEventStore::setStore (tree);
 }
diff --git a/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/ProxyMap.h b/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/ProxyMap.h
index a5de3790a29..b204050a065 100755
--- a/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/ProxyMap.h
+++ b/PhysicsAnalysis/AthenaROOTAccess/AthenaROOTAccess/ProxyMap.h
@@ -23,10 +23,10 @@
 
 #include "AthenaROOTAccess/TTreeBranchMap.h"
 #include "SGTools/StringPool.h"
-#include "SGTools/IProxyDictWithPool.h"
-#include "CxxUtils/unordered_map.h"
+#include "AthenaKernel/IProxyDict.h"
 #include "GaudiKernel/StatusCode.h"
 #include "Rtypes.h"
+#include <unordered_map>
 #include <utility>
 #include <vector>
 
@@ -439,7 +439,7 @@ private:
   /// Type for the proxy map.
   /// We hold payload_t via pointers because we want entries
   /// corresponding to symlinks to point at the same entry.
-  typedef SG::unordered_map<sgkey_t, payload_t*, keyhash> proxymap_t;
+  typedef std::unordered_map<sgkey_t, payload_t*, keyhash> proxymap_t;
 
   /// The actual proxy map.
   proxymap_t m_proxymap;
@@ -453,8 +453,8 @@ private:
   /// Transient tree.
   TTreeBranchMap* m_trans_tree;
 
-  /// Transient tree, cast to IProxyDictWithPool.
-  IProxyDictWithPool* m_trans_tree_dict;
+  /// Transient tree, cast to IProxyDict.
+  IProxyDict* m_trans_tree_dict;
 
   /// Persistent tree.
   TTree* m_pers_tree;
@@ -494,19 +494,19 @@ private:
   {
     std::size_t operator() (const redirect_key_t& key) const
     {
-      SG::hash<std::string> h;
+      std::hash<std::string> h;
       return h (key.m_dbid) + h (key.m_container);
     }
   };
 
-  typedef SG::unordered_map<redirect_key_t, size_t, redirect_key_hash>
+  typedef std::unordered_map<redirect_key_t, size_t, redirect_key_hash>
     redirect_map_t;
 
   /// The redirection map.
   redirect_map_t m_redirectMap;
 
   /// Map from transient objects to pointers.
-  typedef SG::unordered_map<const void*, SG::DataProxy*> transient_map_t;
+  typedef std::unordered_map<const void*, SG::DataProxy*> transient_map_t;
   transient_map_t m_transientMap;
 };
 
-- 
GitLab